document.addEventListener('DOMContentLoaded', () => {
    const chatMessages = document.querySelector('.chat-messages');
    const userInput = document.getElementById('userInput');
    const sendButton = document.getElementById('sendButton');

    function addMessage(message, isUser = false) {
        const messageDiv = document.createElement('div');
        messageDiv.className = `message ${isUser ? 'user' : 'bot'}`;
        const p = document.createElement('p');
        p.textContent = message;
        messageDiv.appendChild(p);
        chatMessages.appendChild(messageDiv);
        chatMessages.scrollTop = chatMessages.scrollHeight;
    }

    function generateResponse(userMessage) {
        const responses = [
            "That's interesting! Tell me more.",
            "I understand. How can I help you with that?",
            "Let me think about that for a moment...",
            "That's a great question! Here's what I think...",
            "I'm processing your request..."
        ];
        return responses[Math.floor(Math.random() * responses.length)];
    }

    function handleUserInput() {
        const message = userInput.value.trim();
        if (message) {
            addMessage(message, true);
            userInput.value = '';
            
            setTimeout(() => {
                const response = generateResponse(message);
                addMessage(response);
            }, 1000);
        }
    }

    sendButton.addEventListener('click', handleUserInput);
    userInput.addEventListener('keypress', (e) => {
        if (e.key === 'Enter') {
            handleUserInput();
        }
    });

    // Add typing animation
    userInput.addEventListener('focus', () => {
        userInput.style.boxShadow = '0 0 0 2px rgba(45, 59, 255, 0.2)';
    });

    userInput.addEventListener('blur', () => {
        userInput.style.boxShadow = 'none';
    });

    // Add smooth scroll for navigation
    document.querySelectorAll('a[href^="#"]').forEach(anchor => {
        anchor.addEventListener('click', function (e) {
            e.preventDefault();
            document.querySelector(this.getAttribute('href')).scrollIntoView({
                behavior: 'smooth'
            });
        });
    });
});